package com.srs.teacher.service;

import java.util.List;

import com.srs.teacher.domain.SysTeacherStuTestMaterials;
import org.apache.ibatis.annotations.Param;

import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 职业测评材料Service接口
 *
 * @author chc
 * @date 2024-06-06
 */
public interface ISysTeacherStuTestMaterialsService extends IService<SysTeacherStuTestMaterials> {

    public SysTeacherStuTestMaterials selectSysTeacherStuTestMaterialsById(Long id);

    /**
     * 查询职业测评材料
     *
     * @param sysTeacherStuTestMaterials 职业测评材料
     * @return 职业测评材料
     */
    public List<SysTeacherStuTestMaterials> selectSysTeacherStuTestMaterialsList(SysTeacherStuTestMaterials sysTeacherStuTestMaterials);

    public List<SysTeacherStuTestMaterials> selectSysTeacherStuTestMaterialsByFdyName(@Param("fdyName") String fdyName, @Param("fillingYear") String fillingYear, @Param("fillingMonth") String fillingMonth);

    /**
     * 新增职业测评材料
     *
     * @param sysTeacherStuTestMaterials 职业测评材料
     * @return 结果
     */
    public int insertSysTeacherStuTestMaterials(SysTeacherStuTestMaterials sysTeacherStuTestMaterials);

    /**
     * 修改职业测评材料
     *
     * @param sysTeacherStuTestMaterials 职业测评材料
     * @return 结果
     */
    public int updateSysTeacherStuTestMaterials(SysTeacherStuTestMaterials sysTeacherStuTestMaterials);

    /**
     * 批量删除职业测评材料
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysTeacherStuTestMaterialsByIds(Long[] ids);

    /**
     * 删除职业测评材料信息
     *
     * @param id 职业测评材料主键
     * @return 结果
     */
    public int deleteSysTeacherStuTestMaterialsById(Long id);
}
