package com.srs.web.controller.teacher;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.annotation.RepeatSubmit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.teacher.domain.SysTeacherStuTestMaterials;
import com.srs.teacher.service.ISysTeacherStuTestMaterialsService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 职业测评材料Controller
 *
 * @author chc
 * @date 2024-06-06
 */
@RestController
@RequestMapping("/teacher/stuTestMaterials")
@Api(value = "职业测评材料管理", tags = "职业测评材料管理")
public class SysTeacherStuTestMaterialsController extends BaseController {
    @Autowired
    private ISysTeacherStuTestMaterialsService sysTeacherStuTestMaterialsService;

    /**
     * 查询职业测评材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:list')")
    @GetMapping("/list")
    @ApiOperation("查询职业测评材料列表")
    public TableDataInfo list(SysTeacherStuTestMaterials sysTeacherStuTestMaterials) {
        startPage();
        List<SysTeacherStuTestMaterials> list = sysTeacherStuTestMaterialsService.selectSysTeacherStuTestMaterialsList(sysTeacherStuTestMaterials);
        return getDataTable(list);
    }

    /**
     * 根据辅导员名称、年份 月份 查询详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:list')")
    @GetMapping("/getByFdyNameAndYearAndMonth")
    @ApiOperation("根据名称年月查询职业测评材料列表")
    public TableDataInfo getByFdyNameAndYearAndMonth(@RequestParam String fdyName, @RequestParam String fillingYear, @RequestParam String fillingMonth) {
        startPage();
        List<SysTeacherStuTestMaterials> list = sysTeacherStuTestMaterialsService.selectSysTeacherStuTestMaterialsByFdyName(fdyName, fillingYear, fillingMonth);
        return getDataTable(list);
    }

    /**
     * 导出职业测评材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:export')")
    @Log(title = "职业测评材料", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出职业测评材料列表")
    public void export(HttpServletResponse response, SysTeacherStuTestMaterials sysTeacherStuTestMaterials) {
        List<SysTeacherStuTestMaterials> list = sysTeacherStuTestMaterialsService.selectSysTeacherStuTestMaterialsList(sysTeacherStuTestMaterials);
        ExcelUtil<SysTeacherStuTestMaterials> util = new ExcelUtil<SysTeacherStuTestMaterials>(SysTeacherStuTestMaterials.class);
        util.exportExcel(response, list, "职业测评材料数据");
    }

    /**
     * 获取职业测评材料详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取职业测评材料详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysTeacherStuTestMaterialsService.selectSysTeacherStuTestMaterialsById(id));
    }

    /**
     * 新增职业测评材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:add')")
    @Log(title = "职业测评材料", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增职业测评材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult add(@RequestBody SysTeacherStuTestMaterials sysTeacherStuTestMaterials) {
        return toAjax(sysTeacherStuTestMaterialsService.insertSysTeacherStuTestMaterials(sysTeacherStuTestMaterials));
    }

    /**
     * 修改职业测评材料
     */
    @PreAuthorize("@ss.hasAnyPermi('teacher:stuActivityMaterials:edit,teacher:stuActivityMaterials:add')")
    @Log(title = "职业测评材料", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改职业测评材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult edit(@RequestBody SysTeacherStuTestMaterials sysTeacherStuTestMaterials) {
        return toAjax(sysTeacherStuTestMaterialsService.updateSysTeacherStuTestMaterials(sysTeacherStuTestMaterials));
    }

    /**
     * 删除职业测评材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:remove')")
    @Log(title = "职业测评材料", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除职业测评材料")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysTeacherStuTestMaterialsService.deleteSysTeacherStuTestMaterialsByIds(ids));
    }
}
